@@ -1,6 +1,7 @@
 package e2e
 
 import (
+	"context"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -12,10 +13,10 @@ import (
 )
 
 func TestOperatorNamespace(t *testing.T) {
-	kubeConfig, err := test.NewClientConfigForTest()
-	require.NoError(t, err)
+	kubeConfig := test.NewClientConfigForTest(t)
+
 	kubeClient, err := kubernetes.NewForConfig(kubeConfig)
 	require.NoError(t, err)
-	_, err = kubeClient.CoreV1().Namespaces().Get("openshift-authentication-operator", metav1.GetOptions{})
+	_, err = kubeClient.CoreV1().Namespaces().Get(context.TODO(), "openshift-authentication-operator", metav1.GetOptions{})
 	require.NoError(t, err)
 }
